==> blue2-theme-neilson-recruitment-1.0.16-461b77.tar: templates/sections/50_50_content_with_optional_left_bg_image.php <==
<?php
$show_social_media_links = get_sub_field("show_social_media_links");
$left_content = get_sub_field("left_content");
$left_bg_image = get_sub_field("left_bg_image");
$right_content = get_sub_field("right_content");
?>
<section class="f_f_content_with_optional_left_bg_image">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-lg-6">
                <div class="row">
                    <div class="col-lg-12 display-top">
                        <div class="left-content">
                            <?=$left_content;?>
                            <?php if ($show_social_media_links[0] == "show") : ?>
                                <div class="social-media">
                                    <ul class="social-media-icons text-sm-center">
                                        <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                        <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                                        <?php endwhile; ?>
                                        <li>Keep up to date!</li>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-12 display-bottom">
                        <img src="<?=$left_bg_image?>" class="left-bg-image" alt="">
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="right-content">
                    <?=$right_content;?>
                </div>
            </div>
        </div>
    </div>
</section>

==> blue2-theme-neilson-recruitment-1.0.28-52661a.tar: templates/sections/50_50_content_with_optional_left_bg_image.php <==
<?php
$show_social_media_links = get_sub_field("show_social_media_links");
$left_content = get_sub_field("left_content");
$left_bg_image = get_sub_field("left_bg_image");
$right_content = get_sub_field("right_content");
?>
<section class="f_f_content_with_optional_left_bg_image">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-lg-6">
                <div class="row">
                    <div class="col-lg-12 display-top">
                        <div class="left-content">
                            <?=$left_content;?>
                            <?php if ($show_social_media_links[0] == "show") : ?>
                                <div class="social-media">
                                    <ul class="social-media-icons text-sm-center">
                                        <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                        <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                                        <?php endwhile; ?>
                                        <li class="socials-tagline">Keep up to date!</li>
                                    </ul>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-12 display-bottom">
                        <img src="<?=$left_bg_image?>" class="left-bg-image" alt="">
                    </div>
                </div>
            </div>
            <div class="col-lg-6">
                <div class="right-content">
                    <?=$right_content;?>
                </div>
            </div>
        </div>
    </div>
</section>
